@@ -4,18 +4,17 @@ from .dmo import *
 from .dto import *
 
 
-def classify(absolute_path: str,
+def classify(d_schema: dict,
              input_tokens: list) -> dict:
     """ Run the Schema Orchestrator
 
     Args:
-        absolute_path (str): absolute path to the location of the classification rules
+        d_schema (dict): the schema JSON
         input_tokens (list): a flat list of tokens extracted from text
             Sample Input:
                 ['network_topology', 'user', 'customer']
     """
-    run = SchemaOrchestrator(
-        schema_file=absolute_path).run
+    run = SchemaOrchestrator(d_schema).run
 
     svcresult = run(input_tokens)
 
