@@ -5,21 +5,18 @@
 """ Portendo performs Predictive Classification of deepNLU parsed ASTs """
 
 
-import os
+from pprint import pprint
 from pprint import pformat
 
 from typing import List
 from typing import Dict
 
-from baseblock import FileIO
-from baseblock import Enforcer
 from baseblock import Stopwatch
 from baseblock import BaseObject
 
 from schema_classification.svc import ReadMapping
-from schema_classification.svc import PredictMapping
+from schema_classification.svc import FilterMapping
 from schema_classification.svc import SelectMapping
-from schema_classification.dmo import InputTokensTransform
 from schema_classification.dto import ServiceEvent
 
 
@@ -63,6 +60,11 @@ class SchemaOrchestrator(BaseObject):
             craigtrim@gmail.com
             *   pass in d-schema as dict rather than a filepath
                 https://github.com/craigtrim/schema-classification/issues/1
+        Updated:
+            30-Nov-2022
+            craigtrim@gmail.com
+            *   use list-of-str for input tokens rather than mapped dict
+                https://github.com/craigtrim/schema-classification/issues/3
 
         Args:
             d_schema (Dict): the schema JSON
@@ -73,18 +75,12 @@ class SchemaOrchestrator(BaseObject):
     def _run(self,
              input_tokens: List[str]) -> ServiceEvent:
 
-        d_tokens = InputTokensTransform(input_tokens).process()
-        input_tokens = [x for x in d_tokens]
-
-        svcresult = {
-            'transform': d_tokens,
-            'input': input_tokens
-        }
-
-        mapping_result_dict = PredictMapping(self._d_index).process(svcresult)
+        # this output dictionary are the classifications that are still valid
+        d_filter = FilterMapping(
+            self._d_index).process(input_tokens)
 
         mapping = SelectMapping(
-            results=mapping_result_dict,
+            d_filter=d_filter,
             d_index=self._d_index).process()
 
         if self.isEnabledForDebug:
@@ -96,16 +92,16 @@ class SchemaOrchestrator(BaseObject):
         if not len(mapping):
             return {
                 'result': None,
-                'tokens': d_tokens
+                'tokens': input_tokens
             }
 
         return {
             'result': mapping,
-            'tokens': d_tokens
+            'tokens': input_tokens
         }
 
     def run(self,
-            input_tokens: list) -> ServiceEvent:
+            input_tokens: List[str]) -> ServiceEvent:
         """ Run the Schema Orchestrator on Input Tokens
 
         Args:
