@@ -58,11 +58,11 @@ class ConfidenceExcludeAllOf(BaseObject):
             confidence -= 99
 
         self.logger.debug('\n'.join([
-            "Exclude All Of Confidence",
-            f"\tExclusions ({len(exclusions)}): {exclusions}",
-            f"\tMarkers ({len(markers)}): {markers}",
-            f"\tMatches: {total_matches}",
-            f"\tRatio: {ratio}"]))
+            'Exclude All Of Confidence',
+            f'\tExclusions ({len(exclusions)}): {exclusions}',
+            f'\tMarkers ({len(markers)}): {markers}',
+            f'\tMatches: {total_matches}',
+            f'\tRatio: {ratio}']))
 
         return confidence
 
