@@ -90,12 +90,12 @@ class ConfidenceIncludeAllOf(BaseObject):
 
                     confidence = compute()
                     self.logger.debug('\n'.join([
-                        "Include All Confidence Computation",
-                        f"\tClassification: {k}",
-                        f"\tUser Tags ({total_usr_tags}): {usr_tags}",
-                        f"\tMapping Tags ({total_map_tags}): {map_tags}",
-                        f"\tMatches ({total_matches}): {matches}",
-                        f"\tConfidence: {confidence}"]))
+                        'Include All Confidence Computation',
+                        f'\tClassification: {k}',
+                        f'\tUser Tags ({total_usr_tags}): {usr_tags}',
+                        f'\tMapping Tags ({total_map_tags}): {map_tags}',
+                        f'\tMatches ({total_matches}): {matches}',
+                        f'\tConfidence: {confidence}']))
 
                     if confidence == 0:
                         continue
