@@ -44,10 +44,10 @@ class Markers(TypedDict):
     marker_type: str
 
 
-InputTags = NewType("InputTags", List[str])
+InputTags = NewType('InputTags', List[str])
 
 
-ListOfDicts = NewType("ListOfDicts", List[Dict[str, Any]])
+ListOfDicts = NewType('ListOfDicts', List[Dict[str, Any]])
 
 
 class ServiceEvent(TypedDict):
@@ -69,7 +69,7 @@ class ComputeOutputResultValue(TypedDict):
 
 
 ComputeOutputResult = NewType(
-    "ComputeOutputResult", Dict[str, ComputeOutputResultValue])
+    'ComputeOutputResult', Dict[str, ComputeOutputResultValue])
 
 
 # Data Flow (RawSchema -> NormalizedSchema)
@@ -78,7 +78,7 @@ RawSchema = NewType(
     # Raw Schema
     # This is the datatype when 'FileIO.read_yaml(schema_file)' is called
     # we don't explicitly declare the attributes, as most are optional
-    "RawSchema",
+    'RawSchema',
     Dict[str, ListOfDicts])
 
 
